
LicenseIT |img|
===============

.. |img| image:: https://s14.postimg.cc/3zf2q1fpd/if_new-24_103173_3.png


1. **Install**
        >>> pip install licenseit

2. **Options**
        >>> licenseit init | new
        >>> license -h | --help
        >>> license -v | --version

3. **Usage**
        >>> licenseit init | new
        >>> Choose a license:
		1. Adaptive public license
		2. Apache license-2.0
		3. Artistic License 2.0
		4. BSD-2-Clause-Patent
		5. BSD-2-Clause
		6. BSD-3-Clause
		7. Common Development and Distribution License
		8. Educational Community License
		9. Eclipse Public License - v 2.0
		10. GNU GENERAL PUBLIC LICENSE 2.0
		11. GNU GENERAL PUBLIC LICENSE 3.0
		12. IPA Font License Agreement v1.0
		13. ISC
		14. GNU LIBRARY GENERAL PUBLIC LICENSE 2.0
		15. GNU LIBRARY GENERAL PUBLIC LICENSE 3.0
		16. MIT
		17. Mozilla Public License, version 2.0
		18. NASA OPEN SOURCE AGREEMENT VERSION 1.3
		19. SIL OPEN FONT LICENSE
		20. OSET PUBLIC LICENSE 2.1
		21. Upstream Compatibility License v. 1.0 (UCL-1.0)
        License (default MIT):
        >>> Author:
        >>> Year: